@@ -160,7 +160,7 @@ class BaseTestCase(unittest.TestCase):
         # parses with self.p and checks att of result
         for test, expected in list(tests.items()):
             if debug:
-                print('"%s"' % test)
+                print(('"%s"' % test))
             s = p.parseString(test)
             if expected is None:
                 expected = test
@@ -171,14 +171,14 @@ class BaseTestCase(unittest.TestCase):
         p = cssutils.CSSParser(raiseExceptions=raising)
         for test, expected in list(tests.items()):
             if debug:
-                print('"%s"' % test)
+                print(('"%s"' % test))
             self.assertRaises(expected, p.parseString, test)
 
     def do_equal_r(self, tests, att='cssText', debug=False):
         # sets attribute att of self.r and asserts Equal
         for test, expected in list(tests.items()):
             if debug:
-                print('"%s"' % test)
+                print(('"%s"' % test))
             self.r.__setattr__(att, test)
             if expected is None:
                 expected = test
@@ -188,14 +188,14 @@ class BaseTestCase(unittest.TestCase):
         # sets self.r and asserts raise
         for test, expected in list(tests.items()):
             if debug:
-                print('"%s"' % test)
+                print(('"%s"' % test))
             self.assertRaises(expected, self.r.__getattribute__(att), test)
 
     def do_raise_r_list(self, tests, err, att='_setCssText', debug=False):
         # sets self.r and asserts raise
         for test in tests:
             if debug:
-                print('"%s"' % test)
+                print(('"%s"' % test))
             self.assertRaises(err, self.r.__getattribute__(att), test)
 
 
