@@ -32,7 +32,7 @@ class CSSutilsTestCase(basetest.BaseTestCase):
     }'''
 
     def test_VERSION(self):
-        self.assertEqual('1.0.1', cssutils.VERSION)
+        self.assertEqual('1.0.2', cssutils.VERSION)
 
     def test_parseString(self):
         "cssutils.parseString()"
@@ -52,8 +52,7 @@ class CSSutilsTestCase(basetest.BaseTestCase):
         irs = ir.styleSheet
         self.assertEqual(cssutils.css.CSSStyleSheet, type(irs))
 
-        href = os.path.join(os.path.dirname(__file__),
-                            '..', '..', '..', 'sheets', 'import.css')
+        href = basetest.get_sheet_filename('import.css')
         href = cssutils.helper.path2url(href)
         s = cssutils.parseString(self.exp,
                                  href=href)
@@ -74,8 +73,7 @@ class CSSutilsTestCase(basetest.BaseTestCase):
     def test_parseFile(self):
         "cssutils.parseFile()"
         # name if used with open, href used for @import resolving
-        name = os.path.join(os.path.dirname(__file__),
-                            '..', '..', '..', 'sheets', 'import.css')
+        name = basetest.get_sheet_filename('import.css')
         href = cssutils.helper.path2url(name)
 
         s = cssutils.parseFile(name, href=href, media='screen', title='from file')
@@ -101,7 +99,7 @@ class CSSutilsTestCase(basetest.BaseTestCase):
         # name is used for open and setting of href automatically
         # test needs to be relative to this test file!
         os.chdir(os.path.dirname(__file__))
-        name = os.path.join('..', '..', '..', 'sheets', 'import.css')
+        name = basetest.get_sheet_filename('import.css')
 
         s = cssutils.parseFile(name, media='screen', title='from file')
         self.assertTrue(isinstance(s, cssutils.css.CSSStyleSheet))
@@ -165,8 +163,7 @@ class CSSutilsTestCase(basetest.BaseTestCase):
 
     def test_parseUrl(self):
         "cssutils.parseUrl()"
-        href = os.path.join(os.path.dirname(__file__),
-                            '..', '..', '..', 'sheets', 'import.css')
+        href = basetest.get_sheet_filename('import.css')
         #href = u'file:' + urllib.pathname2url(href)
         href = cssutils.helper.path2url(href)
         #href = 'http://seewhatever.de/sheets/import.css'
