@@ -277,4 +277,4 @@ def suffix_eq(text, pos, expected):
     if not pos:
         return text == expected
     return (len(text) - pos == len(expected) and
-            all(text[i + pos] == expected[i] for i in range(len(expected))))
+            all(text[i + pos] == expected[i] for i in list(range(len(expected)))))
