@@ -367,7 +367,7 @@ def detectXMLEncoding(fp, log=None, includeDefault=True):
         - if BOM and xml declaration fail, utf-8 is returned according
           to XML 1.0.
     """
-    if PY2x and isinstance(fp, str):
+    if PY2x and isinstance(fp, (str,)):
         fp = io.StringIO(fp)
     elif isinstance(fp, str):
         fp = io.StringIO(fp)
